entry_lexical

Function entry_lexical 

pub fn entry_lexical(e: &SurfaceEntry, goal_terms: &BTreeSet<String>) -> f64
Lexical relevance of an entry to the goal terms: name hits count double, signature hits count single (shared with the task-delta pipeline). Lexical relevance of an entry to the goal terms (engine ranking seam).